@@ -369,11 +369,7 @@ class StandardFunction:
         (function_overall_tension_compression, integration_point_function) = \
             obj_calc.retrieve_functions(selection_tension_compression, integration_point)
 
-        elements_greater_limit = {}
         percentile_values = []
-        for i in time_step_indices:
-            elements_greater_limit[i] = []
-
         element_count = 0
         for part_id in part_ids:
             index = part_idx[part_id]
@@ -388,17 +384,6 @@ class StandardFunction:
                 result_data = function_overall_tension_compression(reduced_integration_point_data, axis=1)
                 result_data = result_data[~np.isnan(result_data)]
 
-                # indices which exceed limit
-                for time_step_id in np.where(result_data >= param_dict[PluginsParamDictDef.LIMIT])[0]:
-                    # when "all" selected time_step_id is correct key
-                    #
-                    # otherwise one time step selected, result time step index key always 0
-                    # although dictionary contains different key
-                    try:
-                        elements_greater_limit[time_step_id].append(element_id)
-                    except:
-                        continue
-
                 # max value for histogram
                 max_value_time_index = np.nanargmax(result_data)
                 max_value = result_data[max_value_time_index]
@@ -420,7 +405,6 @@ class StandardFunction:
                 percentile_limit = percentile_values[int(np.ceil(percentile_value * value_size))]
             else:
                 percentile_limit = percentile_values[int(np.ceil(percentile_upper_limit * value_size))]
-                percentile = round(percentile_upper_limit, 5)
 
         return percentile_limit
 
