@@ -310,9 +310,10 @@ class BinoutData(object):
         if len(dyn_def_key) == 0:
             return True, "temp"
         if self._name == "elout":
-            keys = self._binout.read(self._name)
-            ids_list = np.concatenate([self._binout.read(self._name, elem_name, "ids")[0] if elem_name != "solid" else
-                                       self._binout.read(self._name, elem_name, "ids")  for elem_name in keys])
+            return True, "temp"
+            #keys = self._binout.read(self._name)
+            #ids_list = np.concatenate([self._binout.read(self._name, elem_name, "ids")[0] if elem_name != "solid" else
+            #                           self._binout.read(self._name, elem_name, "ids") for elem_name in keys])
         else:
             ids_list = self._binout.read(self._name, "ids")
         temp_list = []
