@@ -220,6 +220,7 @@ class EloutObject(BinoutData):
         part_data = {}
         part_index = {}
 
+        assert(len(part_ids) > 0)
         for part_id in part_ids:
             index, data = self.get_part_data(strain_stress_idx, part_id, time_step_indices=time_step_indices)
             part_data[part_id] = data
@@ -498,7 +499,7 @@ class EloutObject(BinoutData):
                                                                                                                 1)
 
         if len(mat) == 0 or len(ids) == 0 or len(ipts) == 0:
-            self._logger.emit(LOGConstants.READ_BINOUT[0], ("nothing to extract"))
+            self._logger.emit(LOGConstants.READ_BINOUT[0], "nothing to extract")
             return None
 
         return (np.concatenate((ids, mat, ipts), axis=1)).astype(int)
@@ -664,15 +665,15 @@ class EloutObject(BinoutData):
         self._logger.emit(LOGConstants.READ_BINOUT[0], ("assign strains for " + elout_elem + " elements"))
 
         if elout_elem != "solid" and elout_elem != "shell":
-            self._logger.emit(LOGConstants.READ_BINOUT[0], ("nothing to extract"))
+            self._logger.emit(LOGConstants.READ_BINOUT[0], "nothing to extract")
             return
 
         if elout_elem == "shell" and "lower_eps_xx" not in self._binout.read(self._name, elout_elem):
-            self._logger.emit(LOGConstants.READ_BINOUT[0], ("nothing to extract"))
+            self._logger.emit(LOGConstants.READ_BINOUT[0], "nothing to extract")
             return
 
         if elout_elem == "solid" and "eps_xx" not in self._binout.read(self._name, elout_elem):
-            self._logger.emit(LOGConstants.READ_BINOUT[0], ("nothing to extract"))
+            self._logger.emit(LOGConstants.READ_BINOUT[0], "nothing to extract")
             return
 
         self._logger.emit(LOGConstants.READ_BINOUT[0], "elout: initialize strain " + elout_elem)
